[BusyBox-cvs] busybox/shell ash.c, 1.96, 1.97 cmdedit.c, 1.91, 1.92 hush.c, 1.68, 1.69 msh.c, 1.17, 1.18

Erik Andersen andersen at busybox.net
Wed Apr 14 17:51:38 UTC 2004


Update of /var/cvs/busybox/shell
In directory nail:/tmp/cvs-serv15466/shell

Modified Files:
	ash.c cmdedit.c hush.c msh.c 
Log Message:
Larry Doolittle writes:

This is a bulk spelling fix patch against busybox-1.00-pre10.
If anyone gets a corrupted copy (and cares), let me know and
I will make alternate arrangements.

Erik - please apply.

Authors - please check that I didn't corrupt any meaning.

Package importers - see if any of these changes should be
passed to the upstream authors.

I glossed over lots of sloppy capitalizations, missing apostrophes,
mixed American/British spellings, and German-style compound words.

What is "pretect redefined for test" in cmdedit.c?

Good luck on the 1.00 release!

      - Larry



Index: msh.c
===================================================================
RCS file: /var/cvs/busybox/shell/msh.c,v
retrieving revision 1.17
retrieving revision 1.18
diff -u -d -r1.17 -r1.18
--- a/msh.c	7 Apr 2004 09:34:26 -0000	1.17
+++ b/msh.c	14 Apr 2004 17:51:32 -0000	1.18
@@ -70,7 +70,7 @@
 #define	WAITCORE(s) (((s)&0200)!=0)
 
 /*
- * library and system defintions
+ * library and system definitions
  */
 typedef void xint;	/* base type of jmp_buf, for not broken compilers */
 

Index: hush.c
===================================================================
RCS file: /var/cvs/busybox/shell/hush.c,v
retrieving revision 1.68
retrieving revision 1.69
diff -u -d -r1.68 -r1.69
--- a/hush.c	12 Apr 2004 21:41:29 -0000	1.68
+++ b/hush.c	14 Apr 2004 17:51:31 -0000	1.69
@@ -2646,7 +2646,7 @@
 	mapset(ifs, 2);            /* also flow through if quoted */
 }
 
-/* most recursion does not come through here, the exeception is
+/* most recursion does not come through here, the exception is
  * from builtin_source() */
 int parse_stream_outer(struct in_str *inp, int flag)
 {

Index: cmdedit.c
===================================================================
RCS file: /var/cvs/busybox/shell/cmdedit.c,v
retrieving revision 1.91
retrieving revision 1.92
diff -u -d -r1.91 -r1.92
--- a/cmdedit.c	12 Apr 2004 15:03:51 -0000	1.91
+++ b/cmdedit.c	14 Apr 2004 17:51:31 -0000	1.92
@@ -1,6 +1,6 @@
 /* vi: set sw=4 ts=4: */
 /*
- * Termios command line History and Editting.
+ * Termios command line History and Editing.
  *
  * Copyright (c) 1986-2003 may safely be consumed by a BSD or GPL license.
  * Written by:   Vladimir Oleynik <dzo at simtreas.ru>
@@ -259,7 +259,7 @@
 	putchar('\007');
 }
 
-/* Move back one charactor */
+/* Move back one character */
 /* special for slow terminal */
 static void input_backward(int num)
 {
@@ -429,7 +429,7 @@
 #endif
 
 
-/* draw promt, editor line, and clear tail */
+/* draw prompt, editor line, and clear tail */
 static void redraw(int y, int back_cursor)
 {
 	if (y > 0)                              /* up to start y */
@@ -466,7 +466,7 @@
 }
 
 
-/* Move forward one charactor */
+/* Move forward one character */
 static void input_forward(void)
 {
 	if (cursor < len)




More information about the busybox-cvs mailing list
Index: ash.c
===================================================================
RCS file: /var/cvs/busybox/shell/ash.c,v
retrieving revision 1.96
retrieving revision 1.97
diff -u -d -r1.96 -r1.97
--- a/ash.c	12 Apr 2004 19:12:13 -0000	1.96
+++ b/ash.c	14 Apr 2004 17:51:31 -0000	1.97
@@ -174,7 +174,7 @@
  * We enclose jmp_buf in a structure so that we can declare pointers to
  * jump locations.  The global variable handler contains the location to
  * jump to when an exception occurs, and the global variable exception
- * contains a code identifying the exeception.  To implement nested
+ * contains a code identifying the exception.  To implement nested
  * exception handlers, the user should save the value of handler on entry
  * to an inner scope, set handler to point to a jmploc structure for the
  * inner scope, and restore handler on exit from the scope.
@@ -2702,7 +2702,7 @@
  */
 
 /*
- * The eval commmand.
+ * The eval command.
  */
 
 static int
@@ -7228,7 +7228,7 @@
  * the interactive program catches interrupts, the user doesn't want
  * these interrupts to also abort the loop.  The approach we take here
  * is to have the shell ignore interrupt signals while waiting for a
- * forground process to terminate, and then send itself an interrupt
+ * foreground process to terminate, and then send itself an interrupt
  * signal if the child process was terminated by an interrupt signal.
  * Unfortunately, some programs want to do a bit of cleanup and then
  * exit on interrupt; unless these processes terminate themselves by
@@ -11932,7 +11932,7 @@
 static struct var **findvar(struct var **, const char *);
 
 /*
  * Initialize the varable symbol tables and import the environment
  */
 
 
@@ -12539,7 +12539,7 @@
 /*      $NetBSD: miscbltin.c,v 1.31 2002/11/24 22:35:41 christos Exp $  */
 
 /*
- * Miscelaneous builtins.
+ * Miscellaneous builtins.
  */
 
 #undef rflag
@@ -12911,14 +12911,14 @@
 
 /* This is my infix parser/evaluator. It is optimized for size, intended
  * as a replacement for yacc-based parsers. However, it may well be faster
- * than a comparable parser writen in yacc. The supported operators are
+ * than a comparable parser written in yacc. The supported operators are
  * listed in #defines below. Parens, order of operations, and error handling
- * are supported. This code is threadsafe. The exact expression format should
+ * are supported. This code is thread safe. The exact expression format should
  * be that which POSIX specifies for shells. */
 
 /* The code uses a simple two-stack algorithm. See
  * http://www.onthenet.com.au/~grahamis/int2008/week02/lect02.html
- * for a detailed explaination of the infix-to-postfix algorithm on which
+ * for a detailed explanation of the infix-to-postfix algorithm on which
  * this is based (this code differs in that it applies operators immediately
  * to the stack instead of adding them to a queue to end up with an
  * expression). */
@@ -12948,7 +12948,7 @@
  *    parens and then checking that all binary ops and right parens are
  *    preceded by a valid expression (NUM_TOKEN).
  *
- * Note: It may be desireable to replace Aaron's test for whitespace with
+ * Note: It may be desirable to replace Aaron's test for whitespace with
  * ctype's isspace() if it is used by another busybox applet or if additional
  * whitespace chars should be considered.  Look below the "#include"s for a
  * precompiler test.
@@ -12974,7 +12974,7 @@
  * - realize comma separated - expr, expr
  * - realise ++expr --expr expr++ expr--
  * - realise expr ? expr : expr (but, second expr calculate always)
- * - allow hexdecimal and octal numbers
+ * - allow hexadecimal and octal numbers
  * - was restored loses XOR operator
  * - remove one goto label, added three ;-)
  * - protect $((num num)) as true zero expr (Manuel`s error)
@@ -12989,7 +12989,7 @@
 typedef unsigned char operator;
 
 /* An operator's token id is a bit of a bitfield. The lower 5 bits are the
- * precedence, and 3 high bits are an ID unique accross operators of that
+ * precedence, and 3 high bits are an ID unique across operators of that
  * precedence. The ID portion is so that multiple operators can have the
  * same precedence, ensuring that the leftmost one is evaluated first.
  * Consider * and /. */
@@ -13098,7 +13098,7 @@
 	long contidional_second_val;
 	char contidional_second_val_initialized;
 	char *var;      /* if NULL then is regular number,
-			   else is varable name */
+			   else is variable name */
 } v_n_t;
 
 
@@ -13356,7 +13356,7 @@
 
     /* Stack of integers */
     /* The proof that there can be no more than strlen(startbuf)/2+1 integers
-     * in any given correct or incorrect expression is left as an excersize to
+     * in any given correct or incorrect expression is left as an exercise to
      * the reader. */
     v_n_t *numstack = alloca(((datasizes)/2)*sizeof(v_n_t)),
 	    *numstackptr = numstack;
@@ -11932,7 +11932,7 @@
 
 /*
- * Initialize the varable symbol tables and import the environment
+ * Initialize the variable symbol tables and import the environment
  */
 
